@@ -1,8 +1,11 @@
+import logging
 import sys
 import os
 
 from django.apps import AppConfig
 
+logger = logging.getLogger('django_project_backup.{}'.format(__name__))
+
 
 class DjangoProjectBackupConfig(AppConfig):
     name = 'django_project_backup'
@@ -13,6 +16,8 @@ class DjangoProjectBackupConfig(AppConfig):
         from .settings import REALTIME_BACKUP
 
         if REALTIME_BACKUP:
+            logger.info('django-project-backup realtime enabled')
+
             # disabled while running django "migrate" and "flush" commands
             load_signals = True
             for c in self.excluded_management_commands:
@@ -35,3 +40,5 @@ class DjangoProjectBackupConfig(AppConfig):
 
                 except ImportError:
                     pass
+        else:
+            logger.info('django-project-backup realtime disabled')
