@@ -78,10 +78,12 @@ class DBAdapter:
             _res = self.database.create_document(doc, throw_on_exists=True)
             return True
 
-        except CloudantDatabaseException:
+        except CloudantDatabaseException as e:
+            logger.exception('Error ({}) updating doc "{}"'.format(e, doc['_id']))
             updated = False
 
             while not updated:
+                logger.debug('Retrying to update doc "{}"'.format(doc['_id']))
                 # Upon entry into the document context, fetches the document from the
                 # remote database, if it exists. Upon exit from the context, saves the
                 # document to the remote database with changes made within the context.
@@ -101,7 +103,17 @@ class DBAdapter:
         return self.database.all_docs(include_docs=True)
 
     def delete_document(self, key):
-        to_delete = self.database[key]
-        to_delete.delete()
+        try:
+            self.database[key].delete()
+        except Exception as e:
+            logger.exception('Error ({}) deleting doc "{}"'.format(e, key))
+            deleted = False
+
+            while not deleted:
+                logger.debug('Retrying to delete doc "{}"'.format(key))
+                with Document(self.database, key) as document:
+                    document['_deleted'] = True
+                    # The document is saved (as deleted) to the remote database
+                    deleted = True
 
         return key
